@@ -1,4 +1,5 @@
 import contextlib
+import datetime
 import json
 import logging
 import os
@@ -143,12 +144,13 @@ class Job:
 class JobEnvironment:
     STANDARD_PACKAGES = ['irisml', 'irisml-tasks', 'irisml-tasks-training']
 
-    def __init__(self, base_docker_image, base_docker_image_registry, custom_packages, extra_index_url=None):
+    def __init__(self, base_docker_image, base_docker_image_registry, custom_packages, extra_index_url=None, add_docker_build_date=True):
         self._base_docker_image = base_docker_image
         self._base_docker_image_registry = base_docker_image_registry
         # Make sure it's sorted so that the Docker image will be cached correctly.
         self._pip_packages = sorted(self._add_standard_packages(custom_packages))
         self._extra_index_url = extra_index_url
+        self._add_docker_build_date = add_docker_build_date
 
     @property
     def base_docker_image(self):
@@ -156,6 +158,7 @@ class JobEnvironment:
 
     @property
     def dockerfile(self):
+        label_statement = f'LABEL build-date={datetime.date.today()}' if self._add_docker_build_date else ''
         pip_packages_str = ' '.join([f'"{p}"' for p in self._pip_packages])
         pip_option = f' --extra-index-url {self._extra_index_url}' if self._extra_index_url else ''
         return """FROM ubuntu:20.04
@@ -163,8 +166,9 @@ RUN apt-get update && apt-get install -y --no-install-recommends python3-pip pyt
 RUN python3.8 -m venv /opt/python
 ENV PATH=/opt/python/bin:$PATH
 RUN pip install --disable-pip-version-check --no-cache-dir setuptools wheel
+{}
 RUN pip install {} {}
-""".format(pip_packages_str, pip_option)
+""".format(label_statement, pip_packages_str, pip_option)
 
     def _add_standard_packages(self, custom_packages):
         """Add standard packages so that there are no duplicates."""
