@@ -33,6 +33,7 @@ def main():
     parser.add_argument('--experiment', default=os.getenv('IRISML_AML_EXPERIMENT_NAME', 'irisml'))
     parser.add_argument('--base_docker_image')
     parser.add_argument('--base_docker_image_registry')
+    parser.add_argument('--no_docker_build_date_label', action='store_true')
     parser.add_argument('--use_sp_on_remote', '--sp', action='store_true', help="Use Service Principal id and secret on the AML job.")
 
     args = parser.parse_args()
@@ -50,7 +51,7 @@ def main():
     custom_packages = args.custom_packages
     if args.requirement:
         custom_packages = custom_packages + args.requirement.read_text().splitlines()
-    env = JobEnvironment(args.base_docker_image, args.base_docker_image_registry, custom_packages, args.extra_index_url)
+    env = JobEnvironment(args.base_docker_image, args.base_docker_image_registry, custom_packages, args.extra_index_url, not args.no_docker_build_date_label)
     print(env)
 
     job_manager = AMLJobManager(args.subscription_id, args.workspace, args.experiment, args.compute_target, use_sp_on_remote=args.use_sp_on_remote, cache_url=cache_url)
